# WildTorch

WildTorch: Leveraging GPU Acceleration for High-Fidelity, Stochastic Wildfire Simulations with PyTorch

[![Hatch project](https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg)](https://github.com/pypa/hatch)

See Live Demo at [Hugging Face Space](https://huggingface.co/spaces/xiazeyu/WildTorch)
